Module types

Module types 

Re-exports

pub use entity::*;

Modules

entity
error

Structs

Camera
Represents a camera entity in the VMF file
Cameras
Represents a collection of cameras in the VMF file
Color
Represents an RGB color with three components
Cordon
Represents a cordon entity (tool used to block off parts of the map)
DispInfo
Represents displacement information for terrain
DispTri
Represents a displacement triangle
DispVertex
Represents a displacement vertex
EditorData
Represents editor-specific data for entities and brushes
Group
Side
Represents a side (face) of a solid brush
Solid
Represents a solid brush in the VMF file
VersionInfo
VersionInfo holds the VMF Header information.
ViewSettings
ViewSettings holds all the parameters for an editor
VisGroup
Represents a visgroup in the VMF file Visgroups can be nested and contain properties like name, id, and color
VisGroups
World
Represents the worldspawn entity in a VMF file