Re-exports
pub use entity::*;
Modules
Structs
- Camera
- Represents a camera entity in the VMF file
- Cameras
- Represents a collection of cameras in the VMF file
- Color
- Represents an RGB color with three components
- Cordon
- Represents a cordon entity (tool used to block off parts of the map)
- Disp
Info - Represents displacement information for terrain
- DispTri
- Represents a displacement triangle
- Disp
Vertex - Represents a displacement vertex
- Editor
Data - Represents editor-specific data for entities and brushes
- Group
- Side
- Represents a side (face) of a solid brush
- Solid
- Represents a solid brush in the VMF file
- Version
Info VersionInfoholds the VMF Header information.- View
Settings - ViewSettings holds all the parameters for an editor
- VisGroup
- Represents a visgroup in the VMF file Visgroups can be nested and contain properties like name, id, and color
- VisGroups
- World
- Represents the worldspawn entity in a VMF file